@@ -1,13 +1,13 @@
 ;;; keymap-utils.el --- Keymap utilities  -*- lexical-binding:t -*-
 
-;; Copyright (C) 2008-2025 Jonas Bernoulli
+;; Copyright (C) 2008-2026 Jonas Bernoulli
 
 ;; Author: Jonas Bernoulli <emacs.keymap-utils@jonas.bernoulli.dev>
 ;; Homepage: https://github.com/tarsius/keymap-utils
 ;; Keywords: convenience extensions
 
-;; Package-Version: 4.1.1
-;; Package-Revision: v4.1.1-0-gb230f47067bd
+;; Package-Version: 4.1.2
+;; Package-Revision: v4.1.2-0-ga3c94ce2c191
 ;; Package-Requires: (
 ;;     (emacs  "28.1")
 ;;     (compat "30.1"))
@@ -65,17 +65,17 @@ definition or else the variable which holds the keymap."
 (defun kmu-full-keymap-p (object)
   "Return t if OBJECT is a full keymap.
 A full keymap is a keymap whose second element is a char-table."
-  (if (kmu-prefix-command-p object)
-      (char-table-p (cadr (symbol-function object)))
-    (and (keymapp object)
+  (cond ((kmu-prefix-command-p object)
+         (char-table-p (cadr (symbol-function object))))
+        ((keymapp object)
          (char-table-p (cadr object)))))
 
 (defun kmu-sparse-keymap-p (object)
   "Return t if OBJECT is a sparse keymap.
 A sparse keymap is a keymap whose second element is not a char-table."
-  (if (kmu-prefix-command-p object)
-      (not (char-table-p (cadr (symbol-function object))))
-    (and (keymapp object)
+  (cond ((kmu-prefix-command-p object)
+         (not (char-table-p (cadr (symbol-function object)))))
+        ((keymapp object)
          (not (char-table-p (cadr object))))))
 
 (defun kmu-menu-binding-p (object)
@@ -287,22 +287,21 @@ indentation mechanism:
     _     \"c\" newly-bound-command)"
   (declare (indent 2))
   (let (body)
-    (while args
-      (let ((key (pop args)))
-        (unless (eq key '_)
-          (let ((def (pop args)))
-            (while (eq def '_)
-              (setq def (pop args)))
-            (cl-case def
-              (=)
-              ((> :remove)
-               (unless (cl-member-if (lambda (form)
-                                       (and (eq (car form) 'keymap-set)
-                                            (equal (car (cddr form)) key)))
-                                     body)
-                 (push `(keymap-unset ,mapvar ,key t) body)))
-              (t
-               (push `(keymap-set ,mapvar ,key ,def) body)))))))
+    (while-let ((key (pop args)))
+      (unless (eq key '_)
+        (let ((def (pop args)))
+          (while (eq def '_)
+            (setq def (pop args)))
+          (cl-case def
+            (=)
+            ((> :remove)
+             (unless (cl-member-if (lambda (form)
+                                     (and (eq (car form) 'keymap-set)
+                                          (equal (car (cddr form)) key)))
+                                   body)
+               (push `(keymap-unset ,mapvar ,key t) body)))
+            (t
+             (push `(keymap-set ,mapvar ,key ,def) body))))))
     (if feature
         `(with-eval-after-load ',feature
            (defvar ,mapvar)
@@ -340,26 +339,25 @@ The last event in an event sequence may be a character range.
       (pcase-let ((`(,key ,def) (pop v)))
         (if (vectorp key)
             (push (list key def) vv)
-          (let (beg end mem)
-            (if (consp key)
-                (setq beg (car key) end (cdr key))
-              (when (integerp key)
-                (setq beg key end key)
-                (while (and (setq mem (car (cl-member (1- beg) v :key #'car)))
-                            (equal (cadr mem) def))
-                  (cl-decf beg)
-                  (setq v (remove mem v)))
-                (while (and (setq mem (car (cl-member (1+ end) v :key #'car)))
-                            (equal (cadr mem) def))
-                  (cl-incf end)
-                  (setq v (remove mem v)))))
+          (let (beg end)
+            (cond ((consp key)
+                   (setq beg (car key) end (cdr key)))
+                  ((integerp key)
+                   (setq beg key end key)
+                   (while-let ((mem (cl-find (1- beg) v :key #'car))
+                               (_(equal (cadr mem) def)))
+                     (cl-decf beg)
+                     (setq v (remove mem v)))
+                   (while-let ((mem (cl-find (1+ end) v :key #'car))
+                               (_(equal (cadr mem) def)))
+                     (cl-incf end)
+                     (setq v (remove mem v)))))
             (cond ((or (not beg) (eq beg end))
                    (push (list key def) vv))
                   ((< (- end beg) min)
                    (cl-loop for key from beg to end
                             do (push (list key def) vv)))
-                  (t
-                   (push (list (cons beg end) def) vv)))))))
+                  ((push (list (cons beg end) def) vv)))))))
     (mapcar (lambda (binding)
               (pcase-let ((`(,key ,def) binding))
                 (list (vconcat prefix (if (vectorp key) key (vector key)))
@@ -409,5 +407,6 @@ The last event in an event sequence may be a character range.
 (provide 'keymap-utils)
 ;; Local Variables:
 ;; indent-tabs-mode: nil
+;; lisp-indent-local-overrides: ((cond . 0) (interactive . 0))
 ;; End:
 ;;; keymap-utils.el ends here
